<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>フィルター:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>ターミナルフォントの選択</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>フォント:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>サイズ:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>&amp;Close Tab</source>
        <translation>タブを閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>ターミナルの上下分割(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>アクティブなターミナルをクリア(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>ターミナルの左右分割(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>サブターミナルを折りたたむ(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>&amp;Next Tab</source>
        <translation>次のタブ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>&amp;Previous Tab</source>
        <translation>前のタブ(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>&amp;Previous Tab in History</source>
        <translation>最近使用した前のタブ(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>&amp;Next Tab in History</source>
        <translation>最近使用した次のタブ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Move Tab &amp;Left</source>
        <translation>タブを左へ移動(&amp;L)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Move Tab &amp;Right</source>
        <translation>タブを右へ移動(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Tab</source>
        <translation>タブ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Go to</source>
        <translation>タブへ移動</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>&amp;Top Subterminal</source>
        <translation>上のサブターミナル(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>下のサブターミナル(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>L&amp;eft Subterminal</source>
        <translation>左のサブターミナル(&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>R&amp;ight Subterminal</source>
        <translation>右のサブターミナル(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Copy &amp;Selection</source>
        <translation>選択部分をコピー(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Paste S&amp;election</source>
        <translation>選択部分を貼り付け(&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Handle history...</source>
        <translation>履歴の処理...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>&amp;Save Session</source>
        <translation>セッションを保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>&amp;Load Session</source>
        <translation>セッションを読出(&amp;L)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Rename session</source>
        <translation>タブ名の変更</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>New Tab From &amp;Preset</source>
        <translation>新規タブをプリセットで開く(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>1 &amp;Terminal</source>
        <translation>画面分割なし(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>上下２分割(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>左右２分割(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>4 Terminal&amp;s</source>
        <translation>４分割(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>&amp;Preferences...</source>
        <translation>設定(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Toggle Bookmarks</source>
        <translation>ブックマーク表示の切り替え</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>&amp;Bottom</source>
        <translation>下(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Top</source>
        <translation>上(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;Right</source>
        <translation>右(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Left</source>
        <translation>左(&amp;L)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>&amp;Tabs Layout</source>
        <translation>タブの位置(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;None</source>
        <translation>なし(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>S&amp;crollbar Layout</source>
        <translation>スクロールバーの位置(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;BlockCursor</source>
        <translation>ブロックカーソル(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;UnderlineCursor</source>
        <translation>アンダーラインカーソル(&amp;U)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;IBeamCursor</source>
        <translation>アイビームカーソル(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>カーソルの形(&amp;K)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Exit QTerminal</source>
        <translation>QTerminal の終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Do not ask again</source>
        <translation>次から確認しない</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Are you sure you want to exit?</source>
        <translation>終了してもよろしいですか?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>軽量なマルチプラットフォーム対応のターミナルエミュレーター</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>ブックマーク</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>ターミナルを表示するには [%1] を押します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Paste Clip&amp;board</source>
        <translation>クリップボードの貼り付け(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Zoom &amp;in</source>
        <translation>ズームイン(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>Zoom &amp;out</source>
        <translation>ズームアウト(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Zoom rese&amp;t</source>
        <translation>ズームのリセット(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>&amp;Find...</source>
        <translation>検索(&amp;F)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>&amp;Toggle Menu</source>
        <translation>メニューの表示/非表示(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;New Tab</source>
        <translation>新規タブ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>&amp;New Window</source>
        <translation>新しいウィンドウ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>&amp;Hide Window Borders</source>
        <translation>ウィンドウ枠を隠す(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>&amp;Show Tab Bar</source>
        <translation>タブを表示(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Fullscreen</source>
        <translation>全画面表示</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="550"/>
        <source>Emulation</source>
        <translation>エミュレーション</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>ターミナルの設定</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="31"/>
        <source>Appearance</source>
        <translation>外観</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <location filename="../forms/propertiesdialog.ui" line="575"/>
        <source>Behavior</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="55"/>
        <source>Dropdown</source>
        <translation>ドロップダウン</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="275"/>
        <source>Color scheme</source>
        <translation>配色</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Widget style</source>
        <translation>ウィジェットのスタイル</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="335"/>
        <source>Scrollbar position</source>
        <translation>スクロールバーの位置</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Tabs position</source>
        <translation>タブの位置</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Show the menu bar</source>
        <translation>メニューバーを表示する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="368"/>
        <source>Show a border around the current terminal</source>
        <translation>現在のターミナルの境界を表示する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="358"/>
        <source>Application transparency</source>
        <translation>アプリケーションの透過</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="345"/>
        <source>Terminal transparency</source>
        <translation>ターミナルの透過</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="204"/>
        <source>Start with preset:</source>
        <translation>起動時のプリセット:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="215"/>
        <source>None (single terminal)</source>
        <translation>画面分割なし</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>2 terminals horizontally</source>
        <translation>上下２分割</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>2 terminals vertically</source>
        <translation>左右２分割</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="230"/>
        <source>4 terminals</source>
        <translation>４分割</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="148"/>
        <source>Font</source>
        <translation>フォント</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="428"/>
        <source>Change window title based on current terminal</source>
        <translation>ウィンドウのタイトルを現在のターミナル名にする</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Change window icon based on current terminal</source>
        <translation>ウィンドウのアイコンを現在のターミナルに基づいて変更する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="382"/>
        <source>Enable bi-directional text support</source>
        <translation>双方向テキスト(右横書き・左横書き)のサポートを有効にする</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>Background image:</source>
        <translation>背景画像:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="290"/>
        <source>Select</source>
        <translation>選択</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="452"/>
        <source>Show terminal size on resize</source>
        <translation>ターミナルのサイズ変更時にサイズを表示する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="375"/>
        <location filename="../forms/propertiesdialog.ui" line="408"/>
        <source>px</source>
        <translation>ピクセル</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="325"/>
        <source>Show close button on each tab</source>
        <translation>各タブに閉じるボタンを表示する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Terminal margin</source>
        <translation>ターミナルの余白</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="462"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>フォントに含まれる罫線(Box-drawing characters)を使用する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="469"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Alt キーによってアクティブ化したアクセラレータは、ターミナルに干渉することがあります。</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="472"/>
        <source>No menu bar accelerator</source>
        <translation>メニューバーのアクセラレータを無効にする</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="675"/>
        <source>Action after paste</source>
        <translation>テキスト貼り付け後の動作</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="712"/>
        <source>Confirm multiline paste</source>
        <translation>複数行テキストの貼り付け時に確認する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="753"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>１行のテキストの貼り付け時に改行を取り除く</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="688"/>
        <source>Open new terminals in current working directory</source>
        <translation>新しいターミナルは、現在作業中のディレクトリを開く</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="719"/>
        <source>Save Size when closing</source>
        <translation>閉じる時にサイズを保存する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="760"/>
        <source>Save Position when closing</source>
        <translation>閉じる時に位置を保存する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="736"/>
        <source>Ask for confirmation when closing</source>
        <translation>閉じる時に確認する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="780"/>
        <source>Unlimited history</source>
        <translation>履歴を制限しない</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="746"/>
        <source>History size (in lines)</source>
        <translation>履歴のサイズ (行数)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="705"/>
        <source>Default $TERM</source>
        <translation>$TERM のデフォルト値</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="596"/>
        <source>Start with this size:</source>
        <translation>起動時のサイズ:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="459"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>罫線を QTerminal で内部的に描画するか、基本的なフォントレンダリングライブラリに任して描画するかを指定します。</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>強調色を描画するために太字フォントの使用を切り替えます</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="482"/>
        <source>Use bold font face for intense colors</source>
        <translation>強調色のために太字フォントを使う</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>&amp;Hide Window Borders</source>
        <translation>ウィンドウ枠を隠す(&amp;H)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="559"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;どの動作をエミュレートするかです。これはオペレーティングシステムと一致する必要はありません。&lt;/p&gt;&lt;p&gt;よくわからない場合には、&lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; エミュレーションを使います。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>スクロールバック履歴を含む一時ファイルの名前が引数に渡され、このコマンドが実行されます</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="584"/>
        <source>Handle history command</source>
        <translation>履歴を処理するコマンド</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="603"/>
        <location filename="../forms/propertiesdialog.ui" line="617"/>
        <source> px</source>
        <translation> ピクセル</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="624"/>
        <source>Get current size</source>
        <translation>現在のサイズを取得</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="695"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>新しいタブをアクティブなタブの右側に開く</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="698"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>チェックがオフなら新しいタブが右端に開きます</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="726"/>
        <source>Close tab on middle-click</source>
        <translation>中クリックでタブを閉じる</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="798"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>ショートカットキーを編集するには:
1. その場所をダブルクリックする
2. 希望の組み合わせを押してから離す
3. クリックするか Enter を押す

ショートカットキーを削除または無効にするには、2 番目で(Shift のような)修飾キーのみを押します</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="863"/>
        <source>Height</source>
        <translation>高さ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="873"/>
        <location filename="../forms/propertiesdialog.ui" line="890"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="880"/>
        <source>Width</source>
        <translation>幅</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="936"/>
        <source>Edit bookmark file contents</source>
        <translation>ここでブックマークの内容を編集できます</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="958"/>
        <source>Enable bookmarks</source>
        <translation>ブックマークを利用可能にする</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="967"/>
        <source>Bookmark file</source>
        <translation>ブックマークファイル</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="117"/>
        <location filename="../forms/propertiesdialog.ui" line="389"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="828"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="833"/>
        <source>Key</source>
        <translation>キー割当</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="63"/>
        <source>Bookmarks</source>
        <translation>ブックマーク</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Hide tab bar with only one tab</source>
        <translation>1つのタブしか使用していない場合、タブバーを隠す</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="184"/>
        <source>&amp;Change...</source>
        <translation>変更(&amp;C)...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Cursor shape</source>
        <translation>カーソルの形</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>Fixed tab width:</source>
        <translation>タブタイトルの幅を固定:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="845"/>
        <source>Show on start</source>
        <translation>ドロップダウン起動時に表示する</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="852"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="904"/>
        <source>Shortcut:</source>
        <translation>ショートカット:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="980"/>
        <source>Find...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="989"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>ブックマークファイルの場所を指定します。OwnCloud や Dropbox のようなツールとブックマークを簡単に共有できます。</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="145"/>
        <source>No scrollbar</source>
        <translation>スクロールバーなし</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="145"/>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="145"/>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <source>BlockCursor</source>
        <translation>ブロックカーソル</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <source>UnderlineCursor</source>
        <translation>アンダーラインカーソル</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <source>IBeamCursor</source>
        <translation>アイビームカーソル</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="182"/>
        <source>No move</source>
        <translation>スクロールしない</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="182"/>
        <source>Move start</source>
        <translation>最上部にスクロール</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="182"/>
        <source>Move end</source>
        <translation>最下部にスクロール</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="187"/>
        <location filename="../propertiesdialog.cpp" line="282"/>
        <source>System Default</source>
        <translation>システムの既定</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="375"/>
        <source>Choose a background image</source>
        <translation>背景画像の選択</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="376"/>
        <source>Images (*.bmp *.png *.xpm *.jpg)</source>
        <translation>画像 (*.bmp *.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="439"/>
        <source>Open or create bookmarks file</source>
        <translation>ブックマークファイルを開く、または新規作成</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../termwidget.cpp" line="239"/>
        <source>Show Details...</source>
        <translation>詳細の表示...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="108"/>
        <source>Local Bookmarks</source>
        <translation>ローカルのブックマーク</translation>
    </message>
    <message>
        <location filename="../bookmarkswidget.cpp" line="166"/>
        <source>Synchronized Bookmarks</source>
        <translation>ブックマークの同期</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="78"/>
        <location filename="../tabwidget.cpp" line="232"/>
        <source>Shell No. %1</source>
        <translation>Shell No. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="200"/>
        <source>Tab name</source>
        <translation>タブの名前</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="201"/>
        <source>New tab name:</source>
        <translation>新しいタブの名前:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="221"/>
        <source>Select new tab title color</source>
        <translation>新しいタブタイトルの色を選択</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="242"/>
        <source>Close session</source>
        <translation>タブを閉じる</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="244"/>
        <source>Change title color</source>
        <translation>タブタイトルの色を変更</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>セッションの読込</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>保存されたセッションリスト:</translation>
    </message>
</context>
<context>
    <name>TermWidgetImpl</name>
    <message>
        <location filename="../termwidget.cpp" line="231"/>
        <source>Paste multiline text</source>
        <translation>複数行のテキストを貼り付け</translation>
    </message>
    <message>
        <location filename="../termwidget.cpp" line="232"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>このテキストを貼り付けますか？</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>操作(&amp;A)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>QTerminal について(&amp;A)...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Qt について(&amp;Q)...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Qterminal メインウィンドウ</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
</context>
</TS>
